@@ -168,12 +168,12 @@ get_voice_list (void)
 	GNOME_Speech_VoiceInfo *info;	
 
 	info = GNOME_Speech_VoiceInfo__alloc ();
-	info->language = 0;
+	info->language = CORBA_string_dup("en_US");
 	info->name = CORBA_string_dup ("Kevin");
 	info->gender = GNOME_Speech_gender_male;
 	l = g_slist_prepend (l, info);
 	info = GNOME_Speech_VoiceInfo__alloc ();
-	info->language = 0;
+	info->language = CORBA_string_dup("en_US");
 	info->name = CORBA_string_dup ("Kal");
 	info->gender = GNOME_Speech_gender_male;
 	l = g_slist_prepend (l, info);
@@ -214,7 +214,7 @@ voice_info_list_from_voice_list (GSList *l)
 			(GNOME_Speech_VoiceInfo *) l->data;
 		rv->_buffer[i].name = CORBA_string_dup (info->name);
 		rv->_buffer[i].gender = info->gender;
-		rv->_buffer[i].language = info->language;
+		rv->_buffer[i].language = CORBA_string_dup(info->language);
 		i++;
 		l = l->next;
 	}
